@@ -10,7 +10,7 @@ use Catalyst::Authentication::User::AuthTkt;
 
 __PACKAGE__->mk_accessors(qw( cookie_name aat config debug ));
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -36,11 +36,19 @@ sub new {
     my ( $class, $config, $app ) = @_;
     my $self = $class->SUPER::new(
         { cookie_name => $config->{cookie_name} || 'auth_tkt' } );
+    my @aat_args = ();
+    for my $param (qw( cookie_name domain timeout timeout_refresh )) {
+        if ( exists $config->{$param} ) {
+            push( @aat_args, $param => $config->{$param} );
+        }
+    }
     if ( $config->{conf} ) {
-        $self->{aat} = Apache::AuthTkt->new( conf => $config->{conf} );
+        $self->{aat}
+            = Apache::AuthTkt->new( conf => $config->{conf}, @aat_args );
     }
     elsif ( $config->{secret} ) {
-        $self->{aat} = Apache::AuthTkt->new( secret => $config->{secret} );
+        $self->{aat}
+            = Apache::AuthTkt->new( secret => $config->{secret}, @aat_args );
     }
     else {
         croak "conf or secret configuration required";
@@ -77,6 +85,9 @@ find_user() checks the I<context> request object for a cookie named cookie_name(
 or a param named cookie_name(), in that order. If neither are present, or if
 present but invalid, find_user() returns undef.
 
+See also the 'mock' feature as per the
+example in Catalyst::Authentication::AuthTkt SYNOPSIS.
+
 =cut
 
 sub find_user {
@@ -84,6 +95,24 @@ sub find_user {
 
     $c->log->debug('AuthTkt: authenticating request') if $self->debug;
 
+    # mock feature for development when you just want to mimic cookie
+    # (e.g., when running under localhost or different domain than
+    # your auth server)
+    if ( $self->config->{mock} ) {
+        my %user = %{ $self->config->{mock} };
+
+        $c->log->debug("AuthTkt: using mock user $user{id}") if $self->debug;
+
+        return Catalyst::Authentication::User::AuthTkt->new(
+            {   id     => $user{id},
+                data   => '',
+                ts     => '',
+                tokens => $user{tokens},
+                ticket => 'mock_auth_cookie',
+            }
+        );
+    }
+
     # if no cookie or param, return undef
     my $cookie = $c->req->cookie( $self->cookie_name )
         || $c->req->params->{ $self->cookie_name };
@@ -104,10 +133,10 @@ sub find_user {
 # if the 'ignore_ip' config option were used consistently (i.e. both setting and checking)
 # then this hack would not be necessary, but we can't vouch for how the ticket was set.
     if ( !exists $ENV{REMOTE_ADDR} or $self->config->{use_req_address} ) {
-        $c->log->debug( "setting REMOTE_ADDR to " . $c->req->address )
+        my $ipaddr = $self->config->{use_req_address} || $c->req->address;
+        $c->log->debug("setting REMOTE_ADDR to $ipaddr")
             if $self->debug;
-        $self->aat->{ip_addr} = $self->config->{use_req_address}
-            || $c->req->address;
+        $self->aat->{ip_addr} = $ipaddr;
     }
 
     my $ticket = $self->aat->validate_ticket($t);
@@ -215,7 +244,7 @@ sub renew_ticket {
             : '/',
             domain => defined $existing_cookie->domain
             ? $existing_cookie->domain
-            : ( $self->config->{domain} || $c->req->host ),
+            : ( $authtkt->domain || $c->req->host ),
         };
         $c->log->debug( 'AuthTkt: new cookie: '
                 . dump( $c->response->cookies->{ $self->cookie_name } ) )
@@ -240,8 +269,8 @@ sub expire_ticket {
     my $existing_cookie = $c->req->cookie($cookie_name);
     $existing_cookie->value( [] );
     $existing_cookie->expires( time - 100 );
-    $existing_cookie->domain( $self->config->{domain} )
-        if $self->config->{domain};
+    $existing_cookie->domain( $self->aat->domain )
+        if $self->aat->domain;
     $c->res->cookies->{$cookie_name} = $existing_cookie;
     $c->log->debug( "AuthTkt: cookie reset as " . dump($existing_cookie) )
         if $self->debug;
